Introduction · GitBook

# Welcome to Misago documentation!

Misago is featured internet forum solution developed in accordance with practices and trends currently used in web software development.

Like in any full stack solution, Misago provides different levels of interaction that allow for fullfilling different use cases. People who come to your site to talk with each other and exchange their opinions and knowledge will most likely asociate Misago with what they see in their browsers, while developers that are developing site around Misago will focus on its code, API's and implementations details.

The goal of Misago documentation is to provide refence and explanation of features available on each of the stack's layers.

## Warning!

Documentation is currently in early Work in Progress state. New documents are added as features they cover are implemented, with exception of "Users" part of documentation which will be worked on once Misago reaches beta testing stage.

# results matching ""

# No results matching ""